---
title: <span class="badge object-type-disjunction"></span> InlineScript
---
# <span class="badge object-type-disjunction"></span> InlineScript

## Definition

```python
InlineScript: typing.TypeAlias = typing.Union[str, elasticsearch.ElasticsearchInlineScript]
```
